Instalación de ONLYOFFICE Workspace Community usando parámetros adicionales del script
Introducción
ONLYOFFICE Workspace Community es una versión gratuita del sistema colaborativo desarrollado para gestionar documentos, proyectos, relaciones con clientes y correspondencia de correo electrónico, todo en un solo lugar.
ONLYOFFICE Workspace Community se distribuye como un script de instalación automática para sistemas operativos Linux con Docker instalado. El script configura contenedores Docker con todos los componentes necesarios para el correcto funcionamiento de ONLYOFFICE Workspace Community y es fácil de ejecutar, gestionar y actualizar.
Después de descargar el script de instalación de ONLYOFFICE Workspace Community, es posible que necesites ejecutarlo con parámetros adicionales, por ejemplo, para instalar cada componente en un servidor independiente. Usa el siguiente comando para mostrar la lista de todos los parámetros disponibles del script:
bash workspace-install.sh -h
A continuación encontrarás una breve descripción y algunos ejemplos de uso de estos parámetros.
Nombre de la imagen
| Parámetro | Descripción |
|---|---|
-ci, --communityimage | Nombre de la imagen de ONLYOFFICE Community Server |
-di, --documentimage | Nombre de la imagen de ONLYOFFICE Docs |
-mi, --mailimage | Nombre de la imagen de ONLYOFFICE Mail |
-cpi, --controlpanelimage | Nombre de la imagen de ONLYOFFICE Control Panel |
Estos parámetros especifican el nombre de la imagen a partir de la cual se debe iniciar un contenedor. La imagen especificada debe estar disponible en el repositorio público oficial de Docker Hub.
Ejemplo
bash workspace-install.sh -ims false -di onlyoffice/documentserver -ics true -icp true
Esto ejecutará un contenedor a partir de la imagen especificada de ONLYOFFICE Docs almacenada en el repositorio, además de ejecutar los contenedores de ONLYOFFICE Community Server y ONLYOFFICE Control Panel.
Versión del componente
| Parámetro | Descripción |
|---|---|
-cv, --communityversion | Versión de ONLYOFFICE Community Server |
-dv, --documentversion | Versión de ONLYOFFICE Docs |
-mv, --mailversion | Versión de ONLYOFFICE Mail |
-cpv, --controlpanelversion | Versión de ONLYOFFICE Control Panel |
Estos parámetros permiten instalar una versión específica de un componente si no deseas usar la última versión disponible en el repositorio. De forma predeterminada, se usa una imagen etiquetada como latest para ejecutar el contenedor de cada componente.
Ejemplo
Abre el repositorio de Docker Hub en tu navegador, selecciona el componente y ve a la pestaña Tags para ver todas las etiquetas disponibles. Especifica la versión que deseas instalar para los componentes necesarios:
bash workspace-install.sh -ics true -cv 8.9.0.150 -ids false -icp true -cpv 1.6.0.52 -ims true -md "yourdomain.com"
Esto instalará la versión 8.9.0.150 de ONLYOFFICE Community Server, la versión 1.6.0.52 de ONLYOFFICE Control Panel y la última versión de ONLYOFFICE Mail, ya que su versión no se ha especificado explícitamente.
IP del servidor
| Parámetro | Descripción |
|---|---|
-dip, --documentserverip | Dirección IP de ONLYOFFICE Docs |
-mip, --mailserverip | Dirección IP de ONLYOFFICE Mail |
-mdbip, --mailserverdbip | Dirección IP de la base de datos de ONLYOFFICE Mail |
Estos parámetros se pueden usar para conectar los componentes si los instalas en máquinas independientes.
Ejemplo
bash workspace-install.sh -ics true -icp true -ids false -ims false -dip 192.168.3.202 -es false
Esto instalará ONLYOFFICE Community Server con ONLYOFFICE Control Panel y lo conectará con ONLYOFFICE Docs instalado en otra máquina que tiene la dirección IP 192.168.3.202.
Nombre de dominio de ONLYOFFICE Mail
| Parámetro | Descripción |
|---|---|
-md, --maildomain | Nombre de dominio de ONLYOFFICE Mail |
Este parámetro permite especificar un nombre de dominio personalizado que se usará para ONLYOFFICE Mail.
Ejemplo
bash workspace-install.sh -md "yourdomain.com"
Esto instalará todos los componentes de ONLYOFFICE Workspace Community, incluido ONLYOFFICE Mail, con el nombre de dominio yourdomain.com especificado.
Tu dominio que se utilizará para mantener la correspondencia debe ser válido y estar configurado para esta máquina (es decir, debe tener el registro A correspondiente en la configuración DNS que apunte tu nombre de dominio a la dirección IP de la máquina donde está instalado ONLYOFFICE Mail).
En el comando anterior, el parámetro "yourdomain.com" debe entenderse como un dominio de servicio para ONLYOFFICE Mail. Normalmente se especifica en el registro MX del dominio que se utilizará para mantener la correspondencia. Por regla general, "yourdomain.com" tiene el aspecto de mx1.onlyoffice.com
Actualización de componentes
| Parámetro | Descripción | Valores | Predeterminado |
|---|---|---|---|
-u, --update | úsalo para actualizar los componentes existentes | true|false | false |
Este parámetro instala las últimas versiones de los componentes obsoletos si los componentes correspondientes instalados en tu máquina están desactualizados.
Ejemplo
bash workspace-install.sh -u true
Esto detendrá los contenedores que requieren actualización, los eliminará e iniciará las últimas versiones de los componentes correspondientes de ONLYOFFICE Workspace. Los contenedores cuya versión actual coincida con la última disponible no se verán afectados. Los componentes omitidos durante la instalación anterior también se omitirán. Los datos del portal se conservarán automáticamente.
Credenciales
| Parámetro | Descripción |
|---|---|
-un, --username | nombre de usuario de dockerhub |
-p, --password | contraseña de dockerhub |
Estos parámetros se usan cuando se proporcionan credenciales para acceder a un repositorio de prueba, lo que te permite ejecutar contenedores a partir de las imágenes almacenadas allí.
Ejemplo
bash workspace-install.sh -md "yourdomain.com" -un username -p password
Instalación de componentes
| Parámetro | Descripción | Valores | Predeterminado |
|---|---|---|---|
-ics, --installcommunityserver | instalar ONLYOFFICE Community Server | true|false|pull | true |
-ids, --installdocumentserver | instalar ONLYOFFICE Docs | true|false|pull | true |
-ims, --installmailserver | instalar ONLYOFFICE Mail | true|false|pull | true |
-icp, --installcontrolpanel | instalar ONLYOFFICE Control Panel | true|false|pull | true |
Estos parámetros permiten especificar si se debe instalar un determinado componente. Se pueden usar para instalar cada componente en un servidor independiente.
- Usa el valor
truepara instalar un componente. - Usa el valor
falsepara omitir la instalación de un componente. - Usa el valor
pullpara descargar un componente sin instalarlo.
Ejemplo
bash workspace-install.sh -ims false
Esto instalará todos los componentes de ONLYOFFICE Workspace sin ONLYOFFICE Mail.
bash workspace-install.sh -ics false -ids true -icp false -ims false -es true
Esto omitirá la instalación de ONLYOFFICE Mail, ONLYOFFICE Community Server y ONLYOFFICE Control Panel e instalará únicamente ONLYOFFICE Docs.
Tipo de instalación
| Parámetro | Descripción | Valores | Predeterminado |
|---|---|---|---|
-it, --installation_type | tipo de instalación | WORKSPACE|WORKSPACE_ENTERPRISE | WORKSPACE_ENTERPRISE |
Este parámetro instala la solución especificada: ONLYOFFICE Workspace u ONLYOFFICE Workspace Enterprise Edition.
Ejemplo
bash workspace-install.sh -it GROUPS
Esto instalará la solución ONLYOFFICE Workspace, que incluye los componentes ONLYOFFICE Community Server y ONLYOFFICE Control Panel.
Uso de un componente como servidor externo
| Parámetro | Descripción | Valores | Predeterminado |
|---|---|---|---|
-es, --useasexternalserver | usar como servidor externo | true|false | false |
Este parámetro se usa al instalar componentes en servidores independientes.
- Usa el valor
trueal instalar ONLYOFFICE Docs y ONLYOFFICE Mail en máquinas independientes. - Usa el valor
falseal instalar ONLYOFFICE Community Server junto con ONLYOFFICE Control Panel en una máquina independiente.
Ejemplo
bash workspace-install.sh -ics false -ids false -icp false -ims true -md "yourdomain.com" -es true
Esto omitirá la instalación de ONLYOFFICE Docs, ONLYOFFICE Community Server y ONLYOFFICE Control Panel e instalará únicamente ONLYOFFICE Mail.
bash workspace-install.sh -ics true -icp true -ids false -ims false -dip 192.168.3.202 -es false
Esto instalará ONLYOFFICE Community Server con ONLYOFFICE Control Panel y lo conectará con ONLYOFFICE Docs instalado en otra máquina.
Creación del archivo de swap
| Parámetro | Descripción | Valores | Predeterminado |
|---|---|---|---|
-ms, --makeswap | crear archivo de swap | true|false | false |
Este parámetro crea un archivo de swap de 6 GB. De forma predeterminada se especifica el valor true, por lo que no es necesario indicar este parámetro al ejecutar el script. El archivo de swap se creará automáticamente.
Ejemplo
bash workspace-install.sh -ms false
Si ya existe un archivo de swap, usa este comando para evitar que se cree uno nuevo durante la instalación.
Si ejecutas el script de nuevo sin el parámetro -ms, comprueba si existe onlyoffice_swapfile. Si el archivo de swap ya existe, el script no volverá a crearlo.
Servidor MySQL
| Parámetro | Descripción | Predeterminado |
|---|---|---|
-mysqlh, --mysqlhost | Host del servidor MySQL | localhost |
-mysqlprt, --mysqlport | Puerto del servidor MySQL | 3306 |
-mysqlru, --mysqlrootuser | Usuario root del servidor MySQL | root |
-mysqlrp, --mysqlrootpassword | Contraseña root del servidor MySQL | my-secret-pw |
Si no especificas explícitamente estos parámetros, se usan los valores predeterminados.
Ejemplo
bash workspace-install.sh -mysqlru root -mysqlrp new-secret-pw
Este comando establece una contraseña personalizada para la cuenta root de MySQL durante la instalación de ONLYOFFICE Workspace.
Base de datos de ONLYOFFICE Community Server
| Parámetro | Descripción | Predeterminado |
|---|---|---|
-mysqld, --mysqldatabase | Nombre de la base de datos de ONLYOFFICE Community Server | onlyoffice |
-mysqlu, --mysqluser | Usuario de la base de datos de ONLYOFFICE Community Server | onlyoffice_user |
-mysqlp, --mysqlpassword | Contraseña de la base de datos de ONLYOFFICE Community Server | onlyoffice_pass |
Estos parámetros permiten crear la base de datos de ONLYOFFICE Community Server con un nombre personalizado, junto con un nombre de usuario y una contraseña para una cuenta con permisos de superusuario. Si no especificas explícitamente estos parámetros, se usan los valores predeterminados.
Ejemplo
bash workspace-install.sh -mysqld communitydatabase -mysqlu username -mysqlp password
Base de datos de ONLYOFFICE Mail
| Parámetro | Descripción | Predeterminado |
|---|---|---|
-mysqlmd, --mysqlmaildatabase | Nombre de la base de datos de ONLYOFFICE Mail | onlyoffice_mailserver |
-mysqlmu, --mysqlmailuser | Usuario de la base de datos de ONLYOFFICE Mail | mail_admin |
-mysqlmp, --mysqlmailpassword | Contraseña de la base de datos de ONLYOFFICE Mail | Isadmin123 |
Estos parámetros permiten crear la base de datos de ONLYOFFICE Mail especificando un nombre de base de datos personalizado, así como un nombre de usuario y una contraseña para la cuenta con permisos de superusuario sobre la base de datos creada. Si no especificas explícitamente estos parámetros, se usan los valores predeterminados.
Ejemplo
bash workspace-install.sh -md "mx.yourdomain.com" -mysqlmd maildatabase -mysqlmu username -mysqlmp password
Puerto de ONLYOFFICE Community Server
| Parámetro | Descripción | Predeterminado |
|---|---|---|
-cp, --communityport | Puerto de ONLYOFFICE Community Server | 80 |
Este parámetro cambia el puerto en el que se ejecuta ONLYOFFICE Community Server. El puerto predeterminado es el 80.
Ejemplo
bash workspace-install.sh -cp 8080
Configuración de core.machinekey
| Parámetro | Descripción |
|---|---|
-mk, --machinekey | Configuración de la clave core.machinekey |
Este parámetro permite especificar una machinekey personalizada al instalar ONLYOFFICE Workspace Community.
Este parámetro se escribe en el archivo de configuración /app/onlyoffice/CommunityServer/data/.private/machinekey.
Ejemplo
bash workspace-install.sh -mk yourmachinekey
Configuración del secreto JWT
| Parámetro | Descripción |
|---|---|
-jwt, --jwtsecret | Configuración de la clave secreta JWT |
Este parámetro permite especificar una clave secreta JWT personalizada al instalar ONLYOFFICE Workspace Community. La clave secreta se usa para firmar el token web JSON y validar el token en la solicitud a ONLYOFFICE Docs.
Este parámetro se escribe en los siguientes archivos de configuración (las rutas se indican dentro de los contenedores):
- Para Community Server -
/var/www/onlyoffice/WebStudio/web.appsettings.config - Para Document Server -
/etc/onlyoffice/documentserver/local.json
Ejemplo
bash workspace-install.sh -jwt yoursecret